import React from 'react';
import {Form, Input, Modal, Select,} from 'antd';

export const MembershipModal = ({
                                    visible,
                                    onCreate,
                                    onCancel,
                                    initialData,
                                }) => {
    const [form] = Form.useForm();
    const {Option} = Select;
    const dataStatus = ['Active', 'Inactive']


    return (
        <Modal
            visible={visible}
            title={initialData.id ? "Edit Member" : "Create a new Member"}
            okText={initialData.id ? "Edit" : "Create"}
            cancelText="Cancel"
            onCancel={() => {
                form.resetFields()
                onCancel()
            }}
            onOk={() => {
                form
                    .validateFields()
                    .then(values => {
                        onCreate(values);
                        form.resetFields()
                    })
                    .catch(info => {
                        console.log('Validate Failed:', info);
                    });
            }}
        >
            <Form
                form={form}
                layout="vertical"
                name="form_in_modal"
                initialValues={initialData}
            >
                <Form.Item
                    name="name"
                    label="Name"
                    rules={[{required: true, message: 'Please input Name!'}]}
                >
                    <Input/>
                </Form.Item>
                <Form.Item
                    name="username"
                    label="Username"
                    rules={[{required: true, message: 'Please input Username!'}]}
                >
                    <Input/>
                </Form.Item>
                <Form.Item
                    name="status"
                    label="Status"

                    rules={[{required: true, message: 'Please select Status!'}]}
                >
                    <Select
                        showSearch
                        placeholder="Select Status"
                        optionFilterProp="children"
                        filterOption={(input, option) =>
                            option.children.toLowerCase().indexOf(input.toLowerCase()) >= 0
                        }
                        filterSort={(optionA, optionB) =>
                            optionA.children.toLowerCase().localeCompare(optionB.children.toLowerCase())
                        }
                    >
                        {dataStatus.map(it => {
                            return <Option value={it}>{it}</Option>
                        })}
                    </Select>
                </Form.Item>
            </Form>
        </Modal>
    );
};
